@@ -39,10 +39,11 @@ BuyseTest.options <- function(..., reinitialise = FALSE){
                    conf.level = 0.95,
                    cpus = 1,
                    debug = -1,
+                   engine = "GPC2_cpp",
                    hierarchical = TRUE,
                    keep.pairScore = FALSE,
                    keep.survival = FALSE,
-                   method.inference = "permutation",
+                   method.inference = "u-statistic",
                    scoring.rule = "Peron",               
                    correction.uninf = 0,               
                    n.resampling = 1000,
